@@ -13,7 +13,7 @@
 
 package require Tcl 8.2
 package require cmdline
-package provide fileutil 1.14.11
+package provide fileutil 1.16
 
 namespace eval ::fileutil {
     namespace export \
@@ -21,7 +21,7 @@ namespace eval ::fileutil {
 	    jail stripPwd stripN stripPath tempdir tempfile \
 	    install fileType writeFile appendToFile \
 	    insertIntoFile removeFromFile replaceInFile \
-	    updateInPlace test tempdirReset
+	    updateInPlace test tempdirReset maketempdir
 }
 
 # ::fileutil::grep --
@@ -1420,25 +1420,24 @@ proc ::fileutil::foreachLine {var filename cmd} {
     catch {
 	set code 0
 	set result {}
+	set return 0
 	while {[gets $fp line] >= 0} {
-	    set code [catch {uplevel 1 $cmd} result]
-	    if {($code != 0) && ($code != 4)} {break}
+	    set code [catch {uplevel 1 $cmd} result options]
+	    if {$code == 2} {
+		set return 1
+		set code [dict get $options -code]
+		break
+	    } elseif {$code != 0 && $code != 4} {
+		break
+	    }
 	}
     }
     close $fp
 
-    if {($code == 0) || ($code == 3) || ($code == 4)} {
-        return $result
+    if {$return || $code == 1 || $code > 4} {
+	return -options $options $result
     }
-    if {$code == 1} {
-        global errorCode errorInfo
-        return \
-		-code      $code      \
-		-errorcode $errorCode \
-		-errorinfo $errorInfo \
-		$result
-    }
-    return -code $code $result
+    return $result
 }
 
 # ::fileutil::touch --
@@ -1629,6 +1628,23 @@ proc ::fileutil::fileType {filename} {
                 lappend type executable dos
             }
         }
+    } elseif { $binary && [string match "SQLite format 3\x00*" $test] } {
+	lappend type sqlite3
+
+	# Check for various sqlite-based application file formats.
+	set appid [string range $test 68 71]
+	if {$appid eq "\x0f\x05\x51\x12"} {
+	    lappend type fossil-checkout
+	} elseif {$appid eq "\x0f\x05\x51\x13"} {
+	    lappend type fossil-global-config
+	} elseif {$appid eq "\x0f\x05\x51\x11"} {
+	    lappend type fossil-repository
+	} else {
+	    # encode the appid as hex and append that.
+	    binary scan $appid H8 aid
+	    lappend type A$aid
+	}
+	
     } elseif { $binary && [string match "BZh91AY\&SY*" $test] } {
         lappend type compressed bzip
     } elseif { $binary && [string match "\x1f\x8b*" $test] } {
@@ -1864,6 +1880,56 @@ namespace eval ::fileutil {
     variable tempdirSet 0
 }
 
+# ::fileutil::maketempdir --
+
+proc ::fileutil::maketempdir {args} {
+    return [Normalize [MakeTempDir $args]]
+}
+
+proc ::fileutil::MakeTempDir {config} {
+    # Setup of default configuration.
+    array set options {}
+    set options(-suffix) ""
+    set options(-prefix) "tmp"
+    set options(-dir)    [tempdir]
+
+    # TODO: Check for and reject options not in -suffix, -prefix, -dir
+    # Merge user configuration, overwrite defaults.
+    array set options $config
+
+    # See also "tempfile" below. Could be shareable internal configuration.
+    set chars       abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
+    set nrand_chars 10
+    set maxtries    10
+
+    for {set i 0} {$i < $maxtries} {incr i} {
+	# Build up the candidate name. See also "tempfile".
+	set directory_name $options(-prefix)
+	for {set j 0} {$j < $nrand_chars} {incr j} {
+	    append directory_name \
+		[string index $chars [expr {int(rand() * 62)}]]
+	}
+	append directory_name $options(-suffix)
+	set path [file join $options(-dir) $directory_name]
+
+	# Try to create. Try again if already exists, or trouble
+	# with creation and setting of perms.
+	#
+	# Note: The last looks as if it is able to leave partial
+	# directories behind (created, trouble with perms). But
+	# deleting ... Might pull the rug out from somebody else.
+
+	if {[file exists $path]} continue
+	if {[catch {
+	    file mkdir $path
+	    file attributes $path -permissions 0700
+	}]} continue
+
+	return $path
+    }
+    return -code error "Failed to find an unused temporary directory name"
+}
+
 # ::fileutil::tempfile --
 #
 #   generate a temporary file name suitable for writing to
